.. :changelog:

History
-------

0.1.1 (2015-06-17)
---------------------

* Remove spaces from the summary file column headings.  This will simplify downstream
  analysis in some scripting languages.


0.1.0 (2015-05-21)
---------------------

* First release on GitHub, Read the Docs, and PyPI.
